@@ -65,9 +65,9 @@ class PictureModes(Enum):
     natural = b"03"
     hdr = b"04"
     THX = b"06" # unsupported
-    filmmaker = b"7" # requires firmware 2.0
-    frame_adapt_hdr2 = b"8" # requires firmware 2.0
-    frame_adapt_hdr3 = b"9" # requires firmware 2.0
+    filmmaker = b"\x37" # requires firmware 2.0
+    frame_adapt_hdr2 = b"\x38" # requires firmware 2.0
+    frame_adapt_hdr3 = b"\x39" # requires firmware 2.0
     frame_adapt_hdr = b"0B"
     user1 = b"0C"
     user2 = b"0D"
